/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugs.extension;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.util.Assert;
import org.eclipse.team.bugs.internal.main.StoredProvidersManager;
import org.eclipse.team.bugs.internal.model.IProviderListenerRegistry;
import org.eclipse.team.bugs.model.EventHandler;
import org.eclipse.team.bugs.model.IBugProvider;
import org.eclipse.team.bugs.model.IGenericModel;


/**
 * 
 */
public class Providers implements IAdaptable {
    
    private static Providers fInstance;
    
    private EventHandler fEventHandler;
    
    private final ArrayList fProviders;
    private final HashMap fFactories;
    
    private final StoredProvidersManager fStoredProvidersManager;

    public static Providers getInstance() {
        if (fInstance == null) {
            fInstance= new Providers();
        }
        return fInstance;
    }
    
    public void addProvider(IBugProvider provider, BugProviderFactory factory) {
        fStoredProvidersManager.registerPluginID(factory.getId());
        provider.setEventHandler(fEventHandler);
        fProviders.add(provider);
        fFactories.put(provider, factory);
        Assert.isNotNull(fFactories.get(provider));
        fEventHandler.elementsAdded(null, new IGenericModel [] { provider });
        provider.added(this);
    }
    
    public void removeProvider(IBugProvider model) {
        final BugProviderFactory factory= (BugProviderFactory)fFactories.get(model);
        final String id= factory.getId();
        fStoredProvidersManager.unregisterPluginID(id);
        fProviders.remove(model);
        fEventHandler.elementsRemoved(null, new IGenericModel[] { model });
        model.removed(this);
    }

    public List getProviders() {
        return Collections.unmodifiableList(fProviders);
    }
    
    public IProviderListenerRegistry getListenerRegistry() {
        return fEventHandler;
    }
    
    public BugProviderFactory getFactory(IBugProvider provider) {
        return (BugProviderFactory)fFactories.get(provider);
    }

    /**
     * This class is a singleton.
     */
    private Providers() {
        fEventHandler= new EventHandler();
        fProviders= new ArrayList();
        fFactories= new HashMap();
        fStoredProvidersManager= new StoredProvidersManager();
        
        final Map providers= fStoredProvidersManager.getStoredProviders();
        for (final Iterator iter = providers.keySet().iterator(); iter.hasNext();) {
            final IBugProvider provider= (IBugProvider)iter.next();
            addProvider(provider, (BugProviderFactory)providers.get(provider));
        }
    }

    /* (non-Javadoc)
     * @see org.eclipse.core.runtime.IAdaptable#getAdapter(java.lang.Class)
     */
    public Object getAdapter(Class adapter) {
        return Platform.getAdapterManager().getAdapter(this, adapter);
    }
}
