/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.bugs.internal.registry;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.team.bugs.extension.BugProviderFactory;
import org.eclipse.team.bugs.internal.main.BugsPlugin;

public class BugProviderFactoryDescription {
    
	public static final String ATT_ID = "id"; //$NON-NLS-1$
	public static final String ATT_NAME = "name"; //$NON-NLS-1$
	public static final String ATT_ICON = "icon"; //$NON-NLS-1$
	public static final String ATT_CLASS = "class"; //$NON-NLS-1$
	
	private String fName;
	private String fClassName;
	private String fID;
	private String fIcon;
	private ImageDescriptor fImageDescriptor;
	private BugProviderFactory fCachedFactory;
	
	private IConfigurationElement fConfigElement;

	public BugProviderFactoryDescription(IConfigurationElement e) throws CoreException {
		fConfigElement= e;
		loadFromExtension();
		fCachedFactory= null;
	}

	public IConfigurationElement getConfigurationElement() {
		return fConfigElement;
	}

	public String getIcon() {
		return fIcon;
	}
	
	public String getId() {
		return fID;
	}

	public String getName() {
		return fName;
	}
	
	/**
	 * load a view descriptor from the registry.
	 */
	private void loadFromExtension() throws CoreException {
		fID = fConfigElement.getAttribute(ATT_ID);
		fName = fConfigElement.getAttribute(ATT_NAME);
		fClassName = fConfigElement.getAttribute(ATT_CLASS);
		fIcon = fConfigElement.getAttribute(ATT_ICON);
		// Sanity check.
		if ((fName == null) || (fClassName == null) || (fID == null)) {
		    final String id= fConfigElement.getDeclaringExtension().getNamespace();
		    final String message= "Invalid extension (missing label or class name): " + fID;
		    final IStatus status= new Status(IStatus.ERROR, id, 0, message, null);
			throw new CoreException(status);
		}
	}

	/**
	 * Returns a string representation of this descriptor. For debugging
	 * purposes only.
	 */
	public String toString() {
		return "Bug Provider Factory(" + getId() + ":" + getName() + ")"; //$NON-NLS-2$ //$NON-NLS-3$//$NON-NLS-1$
	}

	/**
	 * This operation may be long-running in case the bundle is not loaded yet.
	 * @return The BugProviderFactory provided by the plug-in.
	 * @throws CoreException
 */
	public BugProviderFactory createFactory() throws CoreException {
	    if (fCachedFactory == null) {
	        fCachedFactory= (BugProviderFactory)fConfigElement.createExecutableExtension(ATT_CLASS); 
	    }
		return fCachedFactory; 
	}


	public ImageDescriptor getImageDescriptor() {
		if (fImageDescriptor != null)
			return fImageDescriptor;
		String iconName = fConfigElement.getAttribute(ATT_ICON);
		if (iconName == null)
			return null;
		fImageDescriptor = BugsPlugin.getImageDescriptorFromExtension(fConfigElement.getDeclaringExtension(), iconName);
		return fImageDescriptor;
	}
}
