/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugs.internal.registry;

import org.eclipse.core.runtime.Platform;
import org.eclipse.team.bugs.internal.main.BugsPlugin;

/**
 * 
 */
public class ExtensionManager {
    
    private static ExtensionManager fInstance= null;
    
    private BugProviderFactoryRegistry fFactoryRegistry;
    private AddProviderWizardRegistry fWizardRegistry;


    private ExtensionManager() {
    }
    
    public static ExtensionManager getInstance() {
        if (fInstance == null) {
            fInstance= new ExtensionManager();
        }
        return fInstance;
    }

	public BugProviderFactoryDescription[] getBugProviderFactoryDescriptions() {
		if (fFactoryRegistry == null) {
			fFactoryRegistry = new BugProviderFactoryRegistry();
			fFactoryRegistry.readRegistry(Platform.getExtensionRegistry(), BugsPlugin.ID, BugProviderFactoryRegistry.PT_BUGPROVIDER);
		}
		return fFactoryRegistry.getBugProviderFactories();
	}
	
	public AddProviderWizardDescription[] getAddProviderWizardDescriptions() {
		if (fWizardRegistry == null) {
			fWizardRegistry = new AddProviderWizardRegistry();
			fWizardRegistry.readRegistry(Platform.getExtensionRegistry(), BugsPlugin.ID, AddProviderWizardRegistry.PT_SYNCHRONIZE_WIZARDS);
		}
		return fWizardRegistry.getAddProviderWizards();
	}

}
