package org.eclipse.team.bugs.internal.views;



import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.SashForm;
import org.eclipse.swt.dnd.Clipboard;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.team.bugs.extension.Providers;
import org.eclipse.team.bugs.internal.views.dnd.DragManager;
import org.eclipse.team.bugs.internal.views.dnd.DropManager;
import org.eclipse.ui.model.BaseWorkbenchContentProvider;
import org.eclipse.ui.model.WorkbenchLabelProvider;
import org.eclipse.ui.part.ViewPart;


/**
 * 
 */
public class BugView extends ViewPart {
    
    private SashForm fSashForm;
    private TreeViewer fTreeViewer;
    private BugViewExtensions fExtensions;
    private BugViewListener fListener;
    private Clipboard fClipboard;
    
    private DragManager fDragManager;
    private DropManager fDropManager;
    
    private final BugModelSelection fSelection;
    
    /**
     * 
     */
    public BugView() {
        fSelection= new BugModelSelection();
    }
    
    public void createPartControl(Composite parent) {
		fSashForm = new SashForm(parent, SWT.VERTICAL);
        
        fTreeViewer= new TreeViewer(fSashForm, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL);
        getSite().setSelectionProvider(fTreeViewer);
        
        fTreeViewer.getControl().setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
        fTreeViewer.setContentProvider(new BaseWorkbenchContentProvider());
        fTreeViewer.setLabelProvider(new WorkbenchLabelProvider());
        fTreeViewer.setInput(Providers.getInstance());
        
        fExtensions= new BugViewExtensions(this);
        
        /**
         * Setting up the tree listener.
         */
        fListener= new BugViewListener(this);
        fTreeViewer.addSelectionChangedListener(fListener);	
        fTreeViewer.addDoubleClickListener(fListener);
        fTreeViewer.addTreeListener(fListener);
        fTreeViewer.addOpenListener(fListener);
        fTreeViewer.getControl().addFocusListener(fListener);
        Providers.getInstance().getListenerRegistry().addProviderListener(fListener);
        
        fDragManager= new DragManager(this);
        fDropManager= new DropManager(this);
        
        /**
         * Setting up the context menu.
         */
        final MenuManager menu = new MenuManager(null);
        menu.setRemoveAllWhenShown(true);
        menu.addMenuListener(fListener);
        final Menu swtMenu= menu.createContextMenu(fTreeViewer.getControl());
        fTreeViewer.getControl().setMenu(swtMenu);
        getSite().registerContextMenu(menu, fTreeViewer);
    }
    

    public void setFocus() {
        fTreeViewer.getControl().setFocus();
    }

    public void dispose() {
        super.dispose();
        fExtensions.dispose();
        Providers.getInstance().getListenerRegistry().removeProviderListener(fListener);
        if (fClipboard != null)
            fClipboard.dispose();
    }
    
    public TreeViewer getViewer() {
        return fTreeViewer;
    }
    
    public BugViewExtensions getExtensions() {
        return fExtensions;
    }
    
    public Composite getCustomControlParent() {
        return fSashForm;
    }
    
    public BugModelSelection getSelection() {
        return fSelection;
    }
    
    public Clipboard getClipboard() {
        if (fClipboard == null) {
            fClipboard= new Clipboard(getSite().getShell().getDisplay());
        }
        return fClipboard;
    }
    
    public DragManager getDragManager() {
        return fDragManager;
    }
    
    public DropManager getDropManager() {
        return fDropManager;
    }
}
