/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugs.internal.wizards;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.jface.viewers.ArrayContentProvider;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.jface.wizard.IWizard;
import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.team.bugs.extension.BugsException;
import org.eclipse.team.bugs.internal.main.BugsPlugin;
import org.eclipse.team.bugs.internal.registry.AddProviderWizardDescription;
import org.eclipse.team.bugs.internal.registry.ExtensionManager;
import org.eclipse.team.bugs.tools.SWTUtils;


final class SelectProviderTypePage extends WizardPage {
    
    private final class ProviderSelectionField implements ISelectionChangedListener {
        
        private IWizard fSelectedWizard;
        
        public ProviderSelectionField(Composite composite) {
            
            final Label btsLabel= new Label(composite, SWT.WRAP);
            btsLabel.setLayoutData(SWTUtils.createHFillGridData());
            btsLabel.setText("Available bug tracking systems:");
            
            final TableViewer viewer= new TableViewer(composite, SWT.V_SCROLL | SWT.BORDER);
            viewer.setContentProvider(new ArrayContentProvider());
            viewer.setLabelProvider(new WizardDescriptorLabelProvider());
            viewer.setInput(ExtensionManager.getInstance().getAddProviderWizardDescriptions());
            viewer.addSelectionChangedListener(this);
            
            final Object object= viewer.getElementAt(0);
            if (object != null) 
                viewer.setSelection(new StructuredSelection(object));
            
            final Control control= viewer.getControl();
            control.setLayoutData(SWTUtils.createHVFillGridData());
            control.setFocus();
        }
        
        public void selectionChanged(SelectionChangedEvent event) {
            
            final IStructuredSelection selection= (IStructuredSelection)event.getSelection();

            if (selection.size() != 1) {
                fSelectedWizard= null;
                setPageComplete(false);
                return;
            }

            final AddProviderWizardDescription description= (AddProviderWizardDescription)selection.getFirstElement();

            try {
                fSelectedWizard = description.createWizard();
                fSelectedWizard.addPages();
                // Ask the container to update button enablement
                setPageComplete(true);
                setDescription(description.getDescription());
            } catch (CoreException e) {
                BugsPlugin.log(BugsException.asBugsException(e));
                setPageComplete(false);
            }
        }
        
        public IWizard getSelectedWizard() {
            return fSelectedWizard;
        }
    }

    private ProviderSelectionField fProviderField;
    
    public SelectProviderTypePage() {
        super("Select Bug System Type");
        setTitle("Select Bug System Type");
    }

    public void createControl(Composite parent) {
        final Composite composite= new Composite(parent, SWT.NONE);
        composite.setLayout(new GridLayout(1, false));
        fProviderField= new ProviderSelectionField(composite);
        setControl(composite);
    }
    
    public IWizard getSelectedWizard() {
        return fProviderField.getSelectedWizard();
    }
    
    public IWizardPage getNextPage() {
        if (getSelectedWizard() != null) {
            return getSelectedWizard().getStartingPage();
        }
        return super.getNextPage();
    }
}