/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugs.model;

import java.util.ArrayList;
import java.util.Iterator;

import org.eclipse.team.bugs.internal.model.IProviderListenerRegistry;

/**
 * 
 */
public class EventHandler implements IProviderListener, IProviderListenerRegistry {

    
    private final ArrayList fListeners;

    public EventHandler() {
        super();
        fListeners= new ArrayList();        
    }
    
    public void addProviderListener(IProviderListener listener) {
        if (!fListeners.contains(listener))
            fListeners.add(listener);
    }
    
    public void removeProviderListener(IProviderListener listener) {
        fListeners.remove(listener);
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugs.model.IProviderListener#modelAdded(org.eclipse.team.bugs.model.IGenericModel)
     */
    public void elementsAdded(IGenericModel parent, IGenericModel[] children) {
        if (children.length == 0)
            return;
        for (final Iterator iter = fListeners.iterator(); iter.hasNext();) {
            final IProviderListener listener = (IProviderListener) iter.next();
            listener.elementsAdded(parent, children);
        }
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugs.model.IProviderListener#modelChanged(org.eclipse.team.bugs.model.IGenericModel)
     */
    public void elementsChanged(IGenericModel [] elements) {
        if (elements.length == 0)
            return;
        for (final Iterator iter = fListeners.iterator(); iter.hasNext();) {
            final IProviderListener listener = (IProviderListener) iter.next();
            listener.elementsChanged(elements);
        }
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugs.model.IProviderListener#modelRemoved(org.eclipse.team.bugs.model.IGenericModel)
     */
    public void elementsRemoved(IGenericModel parent, IGenericModel[] children) {
        if (children.length == 0)
            return;
        for (final Iterator iter = fListeners.iterator(); iter.hasNext();) {
            final IProviderListener listener = (IProviderListener) iter.next();
            listener.elementsRemoved(parent, children);
        }
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugs.model.IProviderListener#refreshingStateChanged(org.eclipse.team.bugs.model.IGenericModel)
     */
}