/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugs.model;


/**
 * 
 */
public interface IProviderListener {

    /**
     * This method is called on the listener if children have been added to a parent node.
     * All children must be children of parent.
     * 
     * @param parent The common parent element of the children.
     * @param children The new children of this parent.
     */
    void elementsAdded(IGenericModel parent, IGenericModel [] children);
    
    /**
     * This method is called when several elements have changed their state. The elements
     * are all assumed to be in the same sub-tree of the model, defined by their provider.
     * So for each two elements a and b, a.getProvider() == b.getProvider().
     * 
     * @param elements The elements that have changed their state.
     */
    void elementsChanged(IGenericModel [] elements);
    
    /**
     * This method is called when children have been removed from a parent node. 
     * @param parent The previous common parent of all children.
     * @param children The children that have been removed.
     */
    void elementsRemoved(IGenericModel parent, IGenericModel [] children);
}
