/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.bugzilla.actions;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.window.Window;
import org.eclipse.team.bugzilla.datatypes.QueryURL;
import org.eclipse.team.bugzilla.dialogs.AddQueryDialog;
import org.eclipse.team.bugzilla.model.BugzillaContainer;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.eclipse.team.bugzilla.model.BugzillaProvider;
import org.eclipse.team.bugzilla.model.BugzillaQuery;
import org.eclipse.team.bugzilla.model.IRemoteModel;
import org.eclipse.team.bugzilla.operations.RefreshOperation;
import org.eclipse.ui.IViewActionDelegate;

/**
 * Add query results to the bugzilla view
 */
public class AddQueryAction extends BugzillaActionDelegate implements IViewActionDelegate {
	
	/* (non-Javadoc)
	 * @see org.eclipse.team.bugzilla.actions.BugzillaActionDelegate#isEnabled()
	 */
	protected boolean isEnabled() throws CoreException {
		final BugzillaContainer container = getSelectedContainer();
		if (container == null)
			return false;
		return container.canModifyChildren();
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.actions.ActionDelegate#run(org.eclipse.jface.action.IAction)
	 */
	public void run(IAction action) {
		final BugzillaContainer container = getSelectedContainer();
		
		final AddQueryDialog dialog= new AddQueryDialog(getTargetPart().getSite().getShell(), 
						((BugzillaProvider)(container.getProvider())).getDataCache().getQueryOptions());
		
		dialog.open();
		if (dialog.getReturnCode() != Window.OK)
			return;
		
		QueryURL queryUrl = dialog.getQuery();
		BugzillaQuery query = getQuery(container, queryUrl.toUrlString());
		if (query == null) {
			query = new BugzillaQuery(container, queryUrl);
			container.addChildren(new BugzillaModel [] { query });
		}
		try {
			new RefreshOperation(getTargetPart(), new IRemoteModel[] { query }).run();
		} catch (InvocationTargetException e) {
			handleError(e);
		} catch (InterruptedException e) {
			// Ignore
		}
	}
	
	private BugzillaQuery getQuery(BugzillaContainer container, String urlString) {
		BugzillaModel[] children = container.getChildren();
		for (int i = 0; i < children.length; i++) {
			BugzillaModel model = children[i];
			if (model instanceof BugzillaQuery) {
				if (urlString.equals(((BugzillaQuery)model).getQueryUrl().toUrlString())) {
					return (BugzillaQuery)model;
				}
			}
		}
		return null;
	}
}
