package org.eclipse.team.bugzilla.actions;

import org.eclipse.compare.CompareWithPatchAction;
import org.eclipse.compare.PatchDialogSettings;
import org.eclipse.core.resources.IWorkspaceRoot;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.dnd.Clipboard;
import org.eclipse.swt.dnd.TextTransfer;
import org.eclipse.swt.dnd.Transfer;
import org.eclipse.team.bugs.extension.IViewerProxy;
import org.eclipse.team.bugzilla.datatypes.AttachmentData;
import org.eclipse.team.bugzilla.model.BugzillaAttachment;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.eclipse.team.bugzilla.tools.IBugzillaSelectionProvider;

public class ApplyPatchAction extends BugzillaAction {

	public ApplyPatchAction(IViewerProxy proxy, IBugzillaSelectionProvider selectionProvider) {
		super("Apply as patch...", proxy, selectionProvider);
	}

	public void setEnablement() {
		BugzillaModel selection = getSelection().getOnlyElement();
		
		if (selection instanceof BugzillaAttachment &&
				((BugzillaAttachment)selection).hasLocalContent() &&
				((BugzillaAttachment)selection).getData().getString(AttachmentData.MIMETYPE).startsWith("text/")) {
			setEnabled(true);
		}
		else {
			setEnabled(false);
		}
        
	}
	
	public void run() {
		/* Copy the patch to the clipboard and run the apply patch action
		 * An alternative implementation could save the patch to disk first.
		 */
		BugzillaAttachment attachment = (BugzillaAttachment)this.getSelection().getOnlyElement();
		Clipboard clipboard = this.getProxy().getClipboard();
		String oldContents = (String)clipboard.getContents(TextTransfer.getInstance());
		clipboard.setContents(
				new String[] { attachment.getDataAsString() }, 
				new Transfer[] { TextTransfer.getInstance() });
		
		
		CompareWithPatchAction compare = new CompareWithPatchAction();
		PatchDialogSettings dialogSettings = new PatchDialogSettings();		
		dialogSettings.setUseClipboard(true);
		compare.setDialogSettings(dialogSettings);
		
		IWorkspaceRoot root= ResourcesPlugin.getWorkspace().getRoot();
		compare.selectionChanged(null, new StructuredSelection(root.getProjects()));
		compare.run(null);
		
		// Restore the original contents of the clipboard
		if (oldContents == null) {
			clipboard.clearContents();
		}
		else {
			clipboard.setContents( new String[] { oldContents }, 
					new Transfer[] { TextTransfer.getInstance() });
		}
	}
}
