/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.actions;

import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.window.Window;
import org.eclipse.team.bugs.extension.IViewerProxy;
import org.eclipse.team.bugzilla.dialogs.MoveDialog;
import org.eclipse.team.bugzilla.model.BugzillaContainer;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.eclipse.team.bugzilla.model.BugzillaProvider;
import org.eclipse.team.bugzilla.tools.BugzillaSelection;
import org.eclipse.team.bugzilla.tools.IBugzillaSelectionProvider;

/**
 * 
 */
public class BugzillaMoveAction extends BugzillaAction {
    
    public BugzillaMoveAction(IViewerProxy proxy, IBugzillaSelectionProvider provider) {
        super("Move...", proxy, provider);
    }
    
    public void run() {

        final BugzillaSelection selection= getValidatedSelection();
        if (selection == null)
            return;
        
        final BugzillaContainer source= selection.getCommonParent();
        final BugzillaProvider provider= (BugzillaProvider)source.getProvider();
                
        final MoveDialog dialog= new MoveDialog(getShell(), provider, selection);
        dialog.open();
        
        if (dialog.getReturnCode() != Window.OK)
            return;
        
        final BugzillaContainer target= dialog.getContainer();

        final BugzillaModel [] newChildren= selection.toBugzillaArray();
        
        for (int i = 0; i < newChildren.length; i++) {
            BugzillaModel model = newChildren[i];
            if (target.contains(model.getID())) {
                if (!MessageDialog.openQuestion(getShell(), "Overwrite?", "There are overlapping elements in the target location. Continue and overwrite all?")) {
                    return;
                }
            }
        }
        source.removeChildren(newChildren);
        target.addChildren(newChildren);
    }

    private BugzillaSelection getValidatedSelection() {
        
        final BugzillaSelection selectionl= getSelection();
        
        if (selectionl.containsReadOnlyElements())
            return null;
        
        final BugzillaContainer container= selectionl.getCommonParent();
        if (container == null || !container.canModifyChildren())
            return null;
        
        return selectionl;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.actions.BugzillaAction#setEnablement()
     */
    public void setEnablement() {
        setEnabled(getValidatedSelection() != null);
    }
}
