/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.actions;

import org.eclipse.swt.dnd.TransferData;
import org.eclipse.team.bugs.extension.IViewerProxy;
import org.eclipse.team.bugzilla.model.BugzillaContainer;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.eclipse.team.bugzilla.tools.IBugzillaSelectionProvider;
import org.eclipse.team.bugzilla.view.BugzillaTransfer;

/**
 * 
 */
public class BugzillaPasteAction extends BugzillaAction {
    
    public BugzillaPasteAction(IViewerProxy proxy, IBugzillaSelectionProvider provider) {
        super("Paste", proxy, provider);
    }
    
    public void run() {

        final BugzillaContainer target= getValidatedTarget();
        if (target == null)
            return;
        
        final BugzillaModel [] elements= getValidatedClipboardContent();
        if (elements == null)
            return;
        
        target.addChildren(elements);
    }
    
    private BugzillaContainer getValidatedTarget() {
        final BugzillaModel selected= getSelection().getOnlyElement();
        if (selected == null)
            return null;
        
        if (!(selected instanceof BugzillaContainer))
            return null;
        
        final BugzillaContainer target= (BugzillaContainer)selected;
        if (!target.canModifyChildren())
            return null;
        
        return target;
    }
    
    private boolean clipboardHasData() {
        final TransferData[] transfers = getProxy().getClipboard().getAvailableTypes();
        final BugzillaTransfer bugzillaTransfer = BugzillaTransfer.getInstance();
        for (int i = 0; i < transfers.length; i++) {
            if (bugzillaTransfer.isSupportedType(transfers[i]))
                return true;
        }
        return false;
    }
    
    private BugzillaModel [] getValidatedClipboardContent() {

        if (!clipboardHasData())
            return null;

        final BugzillaModel [] elements= (BugzillaModel [])getProxy().getClipboard().getContents(BugzillaTransfer.getInstance());

        if (elements == null || elements.length == 0)
            return null;
        
        final BugzillaModel parent= (BugzillaContainer)elements[0].getParent();
        if (!(parent instanceof BugzillaContainer))
            return null;
            
        for (int i = 1; i < elements.length; i++) {
            if (parent != elements[i].getParent())
                return null;
        }
            
        return elements;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.actions.BugzillaAction#setEnablement()
     */
    public void setEnablement() {
        setEnabled(clipboardHasData());
    }
}
