/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.actions;


import org.eclipse.core.runtime.CoreException;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.window.Window;
import org.eclipse.team.bugzilla.dialogs.FolderNameDialog;
import org.eclipse.team.bugzilla.model.BugzillaContainer;
import org.eclipse.team.bugzilla.model.BugzillaFolder;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.eclipse.ui.IViewActionDelegate;

/**
 * 
 */
public class CreateFolderAction extends BugzillaActionDelegate implements IViewActionDelegate {

    public void run(IAction action) {
        
        final BugzillaContainer container= getSelectedContainer();

        final FolderNameDialog dialog= new FolderNameDialog(getTargetPart().getSite().getShell(), container, "Create Folder", "Folder name:", getDefaultName(container));
        
        dialog.open();
        
        if (dialog.getReturnCode() == Window.CANCEL)
            return;
  
        new BugzillaFolder(container, dialog.getName());
    }

    private String getDefaultName(BugzillaContainer container) {
        String proposedName = "New Folder";
        int count = 0;
        boolean checkForDuplicates = true;
        while (checkForDuplicates) {
            checkForDuplicates = false;
            BugzillaModel[] children = container.getChildren();
            for (int i = 0; i < children.length; i++) {
                BugzillaModel model = children[i];
                if (model instanceof BugzillaContainer) {
                    String name = ((BugzillaContainer)model).getName();
                    if (name.equals(proposedName)) {
                        checkForDuplicates = true;
                        break;
                    }
                }
            }
            if (checkForDuplicates) {
                count++;
                proposedName = "New Folder (" + count + ")";
            }
        }
        return proposedName;
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.actions.BugzillaActionDelegate#isEnabled()
     */
    protected boolean isEnabled() throws CoreException {
        final BugzillaContainer container= getSelectedContainer();
        if (container == null)
            return false;
        return container.canModifyChildren();
    }
}
