/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.bugzilla.actions;

import java.io.BufferedOutputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.Platform;
import org.eclipse.core.runtime.preferences.IEclipsePreferences;
import org.eclipse.core.runtime.preferences.IPreferencesService;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.team.bugzilla.model.BugzillaContainer;
import org.eclipse.team.bugzilla.persistence.PersistenceManager;
import org.osgi.service.prefs.Preferences;

/**
 * Export a bugzilla container
 */
public class ExportAction extends BugzillaActionDelegate {
    
    public static final String VERSION_1 = "#org.eclipse.team.bugzilla 1.0"; //$NON-NLS-1$

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.team.bugzilla.actions.BugzillaActionDelegate#isEnabled()
     */
    protected boolean isEnabled() throws CoreException {
        return getSelectedContainer() != null;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.actions.ActionDelegate#run(org.eclipse.jface.action.IAction)
     */
    public void run(IAction action) {
        BugzillaContainer container = getSelectedContainer();
        FileDialog dialog = new FileDialog(getTargetPart().getSite().getShell());
        String filename = dialog.open();
        if (filename != null) {
            OutputStream output = null;
            try {
                IPreferencesService service = Platform.getPreferencesService();
                Preferences node = PersistenceManager.getPreferenceNode(container);
                if (node instanceof IEclipsePreferences) {
		            output = new FileOutputStream(filename);
	                output = new BufferedOutputStream(output);
	                writeVersionIndetifier(output);
		            service.exportPreferences((IEclipsePreferences)node, output, null /* no excludes */);
                }
            } catch (IOException e) {
                ErrorDialog.openError(getTargetPart().getSite().getShell(), null, e.getMessage(), null);
            } catch (CoreException e) {
                ErrorDialog.openError(getTargetPart().getSite().getShell(), null, null, e.getStatus());
            } finally {
                if (output != null)
                    try {
                        output.close();
                    } catch (IOException e1) {
                        // Ignore close error
                    }
            }
        }
    }

    private void writeVersionIndetifier(OutputStream output) throws IOException {
        output.write(VERSION_1.getBytes());
        output.write(System.getProperty("line.separator").getBytes()); //$NON-NLS-1$
    }
}
