/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.bugzilla.actions;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.team.bugzilla.datatypes.AttachmentData;
import org.eclipse.team.bugzilla.model.BugzillaAttachment;

public class SaveAttachmentAction extends BugzillaActionDelegate {

	public boolean isEnabled() {
		
		Object selection = getSelection().getFirstElement();
		if (selection == null) {
			return false;
		}
		
		if (selection instanceof BugzillaAttachment &&
			((BugzillaAttachment)selection).hasLocalContent()) {
			return true;
		}
		return false;
	}
	
	public void run(IAction action) {
		BugzillaAttachment attachment = (BugzillaAttachment)(getSelection().getFirstElement());
		FileDialog dialog = new FileDialog(getTargetPart().getSite().getShell(), SWT.SAVE);
		dialog.setFileName(attachment.getData().getString(AttachmentData.FILENAME));
		String filename = dialog.open();
		if (filename != null) {
			File file = new File(filename);
			
			BufferedWriter writer = null;
			
			if (file.exists()) {
				MessageDialog m = new MessageDialog(getTargetPart().getSite().getShell(), 
						"Overwrite " + filename + "?", null, "The file '" + filename +
						"' already exists, overwrite?", MessageDialog.WARNING, 
						new String[] {"Overwrite", "Cancel"}, 1);
				
				if (m.open() == 1) {
					return;
				}
				else {
					file.delete();
				}
				
			}
			
			try {
				if (!file.createNewFile() || !file.canWrite()) {
					MessageDialog.openError(getTargetPart().getSite().getShell(), "Error writing file",
							"Could not write '" + filename + "'");
					return;
				}
				
				writer = new BufferedWriter(new FileWriter(file));
				writer.write(attachment.getDataAsString());
				
			} catch (SecurityException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			} finally {
				if (writer != null) {
					try {
						writer.close();
					} catch (IOException e) {
						e.printStackTrace();
					}
				}

			}
		}
	}
}
