/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.actions;


import org.eclipse.team.bugs.extension.IViewerProxy;
import org.eclipse.team.bugzilla.browser.BugzillaBrowser;
import org.eclipse.team.bugzilla.browser.IWebContentAdapter;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.eclipse.team.bugzilla.model.BugzillaProvider;
import org.eclipse.team.bugzilla.tools.IBugzillaSelectionProvider;

/**
 * 
 */
public class ShowInBrowserAction extends BugzillaAction {
    
    public ShowInBrowserAction(IViewerProxy proxy, IBugzillaSelectionProvider provider) {
        super("Show in Browser", proxy, provider);
    }
    
    public void run() {
        
        String url = getURL();
        if (url == null) {
            return;
        }
        
        url = url.replaceAll("format=rdf", "");
        final BugzillaModel selected = getSelection().getOnlyElement();

        BugzillaBrowser.open(getPart(), (BugzillaProvider)selected.getProvider(), url);
    }

    private String getURL() {
        final BugzillaModel element= getSelection().getOnlyElement();
        if (element == null)
            return null;

        final IWebContentAdapter adapter= (IWebContentAdapter)element.getAdapter(IWebContentAdapter.class);
        if (adapter == null)
            return null;
        return adapter.getURL(element);
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.actions.BugzillaAction#setEnablement()
     */
    public void setEnablement() {
        setEnabled(getURL() != null);
    }
}
