/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.actions;

import org.eclipse.swt.custom.StyledText;
import org.eclipse.team.bugzilla.view.BugzillaViewExtension;
import org.eclipse.team.bugzilla.view.TextPane;

/**
 * 
 */
public class TextSelectAllAction extends BugzillaAction {
    
    private final BugzillaViewExtension fExtension; 

    public TextSelectAllAction(BugzillaViewExtension extension) {
        super("Select all", extension.getProxy(), extension.getBugzillaSelectionProvider());
        fExtension= extension;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.jface.action.Action#run()
     */
    public void run() {
        final StyledText text= getStyledText();
        if (text == null)
            return;
        text.setSelection(0, text.getCharCount());
    }

    public void setEnablement() {
        final StyledText text= getStyledText();
        setEnabled(text != null && text.isFocusControl());
    }
    
    private StyledText getStyledText() {
        final TextPane pane= fExtension.getTextPane();
        if (pane == null)
            return null;
        return pane.getStyledText();
    }
}
