/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.adapters;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.graphics.FontData;
import org.eclipse.team.bugzilla.BugzillaImages;
import org.eclipse.team.bugzilla.browser.IWebContentAdapter;
import org.eclipse.team.bugzilla.datatypes.AttachmentDescription;
import org.eclipse.team.bugzilla.model.BugzillaAttachment;
import org.eclipse.team.bugzilla.view.BugzillaModelPresenter;
import org.eclipse.team.bugzilla.view.IPresentableAdapter;

/**
 * 
 */
public class BugzillaAttachmentAdapter extends ModelElementAdapter implements IPresentableAdapter, IWebContentAdapter {

    public BugzillaAttachmentAdapter() {
        super();
    }

    public void present(Object presentable, StyledText styledText) {

        if (!(presentable instanceof BugzillaAttachment)) 
            return;
        
        new BugzillaModelPresenter().present((BugzillaAttachment)presentable, styledText);
    }

    protected ImageDescriptor doGetImageDescriptor(Object object) {
        final BugzillaAttachment attachment= (BugzillaAttachment)object;
        return attachment.getData() != null ? BugzillaImages.ATTACHMENT: BugzillaImages.INCOMPLETE_ATTACHMENT;
    }

    public String getLabel(Object o) {
        final BugzillaAttachment attachment= (BugzillaAttachment)o;
        return attachment.isRefreshing() ? getRefreshingLabel("attachment " + attachment.getID()) : getStandardLabel(attachment); 
    }

    /**
     * @param attachment
     * @return String
     */
    private String getStandardLabel(final BugzillaAttachment attachment) {
        final StringBuffer label= new StringBuffer();
        
        if (attachment.getDescription().getBoolean(AttachmentDescription.OBSOLETE)) 
            label.append("[OBSOLETE]  ");
        
        label.append("[").append(attachment.getDescription().getString(AttachmentDescription.ID)).append("]  ");
        
        if (attachment.hasLocalContent())
            label.append(attachment.getDescription().getString(AttachmentDescription.DESCRIPTION));
        
        return label.toString();
    }

    public String getURL(Object o) {
        return null;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.adapters.ModelElementAdapter#getFont(java.lang.Object)
     */
    public FontData getFont(Object element) {
        final BugzillaAttachment attachment= (BugzillaAttachment)element;
        if (attachment.isRefreshing())
            return getRefreshingFont();
        return super.getFont(element);
    }
}
