/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.adapters;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.graphics.FontData;
import org.eclipse.team.bugzilla.BugzillaImages;
import org.eclipse.team.bugzilla.browser.IWebContentAdapter;
import org.eclipse.team.bugzilla.datatypes.CommentData;
import org.eclipse.team.bugzilla.model.BugzillaAttachment;
import org.eclipse.team.bugzilla.model.BugzillaComment;
import org.eclipse.team.bugzilla.model.BugzillaProvider;
import org.eclipse.team.bugzilla.model.BugzillaReport;
import org.eclipse.team.bugzilla.operations.CachedOperations;
import org.eclipse.team.bugzilla.view.BugzillaModelPresenter;
import org.eclipse.team.bugzilla.view.IPresentableAdapter;

/**
 * 
 */
public class BugzillaCommentAdapter extends ModelElementAdapter implements IPresentableAdapter, IWebContentAdapter {
   
    public BugzillaCommentAdapter() {
    }

    public void present(Object presentable, StyledText styledText) {

        if (!(presentable instanceof BugzillaComment)) 
            return;
        
        new BugzillaModelPresenter().present((BugzillaComment)presentable, styledText);
     }

    public Object[] getChildren(Object o) {
        final BugzillaAttachment attachment= ((BugzillaComment)o).getAttachment();
        return attachment != null ? new Object[] { attachment } : new Object [0];
    }

    protected ImageDescriptor doGetImageDescriptor(Object object) {
        return BugzillaImages.COMMENT;
    }

    public String getLabel(Object o) {
        final CommentData commentData=  ((BugzillaComment)o).getCommentData();
        return commentData.getString(CommentData.AUTHOR) + "      [" + format(commentData.getDate(CommentData.DATE)) + "]";
    }
    
    public String getURL(Object o) {
        final BugzillaComment comment= (BugzillaComment)o;
        final BugzillaReport report= comment.getReport();
        final BugzillaProvider provider= (BugzillaProvider)comment.getProvider();
        final CachedOperations operations= provider.getOperations();
        if (operations.isCached())
            return operations.getOperations().getCommentURL(provider.getConfiguration(), report.getID(), report.getComments().indexOf(comment));
        return null;
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.adapters.ModelElementAdapter#getFont(java.lang.Object)
     */
    public FontData getFont(Object element) {
        if (((BugzillaComment)element).isRefreshing())
            return getRefreshingFont();
        return super.getFont(element);
    }
}
