/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.bugzilla.adapters;

import java.text.DateFormat;
import java.util.Date;

import org.eclipse.jface.resource.CompositeImageDescriptor;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.resource.JFaceResources;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.FontData;
import org.eclipse.swt.graphics.ImageData;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.team.bugzilla.BugzillaImages;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.eclipse.ui.model.IWorkbenchAdapter;
import org.eclipse.ui.model.IWorkbenchAdapter2;

/**
 * Abstract superclass for bugzilla workbench adapters
 */
public abstract class ModelElementAdapter implements IWorkbenchAdapter, IWorkbenchAdapter2 {
    
    protected static final RGB RED;
    protected static final RGB BLACK;
    protected static final RGB WHITE;
    
    protected static final FontData BOLD_FONT;
    protected static final FontData ITALIC_FONT;
    protected static final FontData NORMAL_FONT;
    
    static {
        NORMAL_FONT= JFaceResources.getDefaultFont().getFontData()[0];
        
        ITALIC_FONT= JFaceResources.getDefaultFont().getFontData()[0];
        ITALIC_FONT.setStyle(SWT.ITALIC);
        
        BOLD_FONT= JFaceResources.getDefaultFont().getFontData()[0];
        BOLD_FONT.setStyle(SWT.BOLD);
        
        BLACK= new RGB(0, 0, 0);
        RED= new RGB(255, 0, 0);
        WHITE= new RGB(255, 255, 255);
        
    }
    
    private static class ErrorDescriptor extends CompositeImageDescriptor {
        
        private final ImageData fData;
        
        ErrorDescriptor(ImageDescriptor original) {
            fData= original.getImageData();            
        }

        protected void drawCompositeImage(int width, int height) {
            ImageData 	overlay= BugzillaImages.ERRORMARKER.getImageData();
            drawImage(fData, 0, 0);
            drawImage(overlay, 0, fData.height - overlay.height);
        }

        protected Point getSize() {
            return new Point(fData.width, fData.height);
        }
    }

    protected final static String format(Date date) {
        return DateFormat.getDateTimeInstance().format(date);
    }
    
	 /* (non-Javadoc)
	 * @see org.eclipse.ui.model.IWorkbenchAdapter#getParent(java.lang.Object)
	 */
    public Object getParent(Object o) {
        if (o instanceof BugzillaModel)
            return ((BugzillaModel)o).getParent();
        return null;
    }
    
    public Object[] getChildren(Object o) {
        return new Object[0];
    }
    
    protected static String getRefreshingLabel(String name) {
        return "Refreshing " + name + "...";
    }
    
    protected static FontData getRefreshingFont() {
        return ITALIC_FONT;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.ui.model.IWorkbenchAdapter2#getBackground(java.lang.Object)
     */
    public RGB getBackground(Object element) {
        return null;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.ui.model.IWorkbenchAdapter2#getForeground(java.lang.Object)
     */
    public RGB getForeground(Object element) {
        return null;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.ui.model.IWorkbenchAdapter2#getFont(java.lang.Object)
     */
    public FontData getFont(Object element) {
        return NORMAL_FONT;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.ui.model.IWorkbenchAdapter#getImageDescriptor(java.lang.Object)
     */
    public final ImageDescriptor getImageDescriptor(Object object) {
        final ImageDescriptor descriptor= doGetImageDescriptor(object);
        if (((BugzillaModel)object).hadErrors()) {
            return new ErrorDescriptor(descriptor);
        }
        return descriptor;
    }
    
    protected abstract ImageDescriptor doGetImageDescriptor(Object object);
}
