/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.browser;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.SWTException;
import org.eclipse.swt.browser.Browser;
import org.eclipse.swt.browser.LocationEvent;
import org.eclipse.swt.browser.LocationListener;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.team.bugs.extension.BugsException;
import org.eclipse.team.bugzilla.BugzillaPlugin;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.IEditorSite;
import org.eclipse.ui.IReusableEditor;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.part.EditorPart;

/**
 * 
 */
public class BugzillaBrowser extends EditorPart implements IReusableEditor, LocationListener {
    
    public final static String ID= "org.eclipse.team.bugzilla.bugzillaBrowser";
    
    public static BugzillaBrowserInput sEditorInput= new BugzillaBrowserInput();
    
    public final static void open(IWorkbenchPart part, LocationListener listener, String url) {
        try {
            sEditorInput.setURL(url);
            sEditorInput.setLocationListener(listener);
            final IEditorPart editor = part.getSite().getPage().findEditor(sEditorInput);
            
            if (editor instanceof BugzillaBrowser) {
                ((BugzillaBrowser)editor).update();
            }
            part.getSite().getPage().openEditor(sEditorInput, ID);

        } catch (PartInitException e) {
            BugzillaPlugin.getDefault().getLog().log(e.getStatus());
        }
    }
    
    private Browser fBrowser;
    private BugzillaBrowserInput fInput;

    public BugzillaBrowser() {
        super();
    }

    public void createPartControl(Composite parent) {
        try {
            fBrowser= new Browser(parent, SWT.NONE);
            fBrowser.setUrl(fInput.getURL().toString());
            fBrowser.addLocationListener(this);
        } catch (SWTException e) {
            BugzillaPlugin.log(BugsException.asBugsException(e));
        }
    }

    public void setFocus() {
        if (fBrowser == null)
            return;
        fBrowser.setFocus();
    }

    public void doSave(IProgressMonitor monitor) {
    }

    public void doSaveAs() {
    }

    public void init(IEditorSite site, IEditorInput input) throws PartInitException {
        setSite(site);
		setInput(input);
    }

    public boolean isDirty() {
        return false;
    }

    public boolean isSaveAsAllowed() {
        return false;
    }
    
    public void update() {
        if (fBrowser == null || fInput.getURL() == null) 
            return;
        fBrowser.setUrl(fInput.getURL());
    }
    
    public void setInput(IEditorInput input) {
        super.setInput(input);
        if (!(input instanceof BugzillaBrowserInput))
            return;
        fInput= (BugzillaBrowserInput)input;
    }

	public void changing(LocationEvent event) {
		LocationListener locationListener = sEditorInput.getLocationListener();
		if(locationListener != null)
			locationListener.changing(event);
	}

	public void changed(LocationEvent event) {
		LocationListener locationListener = sEditorInput.getLocationListener();
		if(locationListener != null)
			locationListener.changed(event);
	}
}
