/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.datatypes;

import java.util.Collection;
import java.util.LinkedHashSet;
import java.util.Map;



public class CommentData extends Data implements Comparable {
    
    public final static String AUTHOR= "0";
    public final static String DATE= "1";
    public final static String TEXT= "2";
    
    private final static LinkedHashSet sSet;
    
    static {
        sSet= new LinkedHashSet();
        sSet.add(AUTHOR);
        sSet.add(DATE);
        sSet.add(TEXT);
    }
    
    public AttachmentDescription attachmentDesc;
    
    public CommentData(Map fields){
    	this.set(CommentData.AUTHOR, (String)fields.get("name"));
    	this.set(CommentData.DATE, (String)fields.get("time"));
    	this.set(CommentData.TEXT, (String)fields.get("body"));
    	
    }
    public CommentData() {
        attachmentDesc= null;
    }
    
    public String toString() {
        final StringBuffer buffer= new StringBuffer();
        final String nl= System.getProperty("line.separator"); //$NON-NLS-1$
        buffer.append("Author: ").append(getString(AUTHOR)).append(nl); //$NON-NLS-1$
        buffer.append("Date: ").append(getString(DATE)).append(nl); //$NON-NLS-1$
        buffer.append("Text: ").append(getString(TEXT)).append(nl); //$NON-NLS-1$
        return buffer.toString();
    }

    public int compareTo(Object o) {
        return getDate(DATE).compareTo(((CommentData)o).getDate(DATE));
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof CommentData))
            return false;
        final CommentData other = (CommentData)obj;
        return getString(TEXT).equals(other.getString(TEXT)) && getString(AUTHOR).equals(other.getString(AUTHOR)) && getDate(DATE).equals(other.getDate(DATE)); 
    }

    protected Collection getKeys() {
        return sSet;
    }

    public String getId() {
        return getDate(DATE).toString();
    }
}
