/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.bugzilla.datatypes;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.runtime.Status;

/**
 * The data returned from a bugzilla query represented as a list of <code>ReportData</code>s.
 */
public class QueryData {

    List reports = new ArrayList();
    
    private List errors = new ArrayList();
    
    /**
     * Add the report to the query result
     * @param report
     */
    public void addBug(ReportData report) {
        reports.add(report);
    }

    /**
     * Add the error status to the query result
     * @param status a error that occurred while fetching
     */
    public void addError(Status status) {
        errors.add(status);
    }

    /**
     * Return an array of <code>ReportData</code>s representing all bugs returned as part
     * of this query.
     * @return an array of <code>ReportData</code>s representing all bugs returned as part
     * of this query
     * 
     */
    public ReportData[] getReportDatas() {
        return (ReportData[]) reports.toArray(new ReportData[reports.size()]);
    }

}
