/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.dialogs;

import java.util.Iterator;

import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.viewers.ViewerFilter;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.team.bugs.dialogs.StatusDialog;
import org.eclipse.team.bugs.extension.Providers;
import org.eclipse.team.bugs.tools.SWTUtils;
import org.eclipse.team.bugzilla.model.BugzillaContainer;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.eclipse.team.bugzilla.model.BugzillaProvider;
import org.eclipse.ui.model.BaseWorkbenchContentProvider;
import org.eclipse.ui.model.WorkbenchLabelProvider;

/**
 * 
 */
public class MoveDialog extends StatusDialog {
    
    
    private final class LocationSelectorField implements ISelectionChangedListener {

        private final class Filter extends ViewerFilter {
            public boolean select(Viewer viewer, Object parentElement, Object element) {
                return element instanceof BugzillaContainer && ((BugzillaContainer)element).getProvider() == fProvider;
            }
        }
        
        private final TreeViewer fViewer;
        private BugzillaContainer fSelected;
        
        public LocationSelectorField(Composite composite) {
            
            fSelected= fProvider;
            
            final Label label= new Label(composite, SWT.WRAP);
            label.setLayoutData(SWTUtils.createHFillGridData());
            label.setText("Move to:");
            label.setLayoutData(SWTUtils.createHFillGridData());
            
            fViewer= new TreeViewer(composite, SWT.BORDER);
            fViewer.getControl().setLayoutData(SWTUtils.createHVFillGridData());
            fViewer.setContentProvider(new BaseWorkbenchContentProvider());
            fViewer.addFilter(new Filter());
            fViewer.setLabelProvider(new WorkbenchLabelProvider());
            fViewer.setInput(Providers.getInstance());
            fViewer.expandAll();
            fViewer.setSelection(new StructuredSelection(fSelected));
            fViewer.addSelectionChangedListener(this);
        }
        
        public BugzillaContainer getSelection() {
            return fSelected;
        }

        public void selectionChanged(SelectionChangedEvent event) {
            final IStructuredSelection selection= (IStructuredSelection)event.getSelection();
            fSelected= (BugzillaContainer)selection.getFirstElement();
            setErrorMessage(this, isValidTarget(fSelected, fSource) ? null : "Target is read-only or contained within the selection.");
        }
        
        private boolean isValidTarget(BugzillaContainer target, IStructuredSelection selection) {
            if (!target.canModifyChildren())
                return false;

            for (Iterator iter = selection.toList().iterator(); iter.hasNext();) {
                final BugzillaModel current= (BugzillaModel)iter.next();
                
                if (current.getParent() == target)
                    return false;
                
                if (target.hasParent(current))
                    return false;
            }
            return true;
        }
    }
    
    private static final int HEIGHT_OFFSET = 14;
    
    private LocationSelectorField fSelector;
    
    protected final BugzillaProvider fProvider;

    protected final IStructuredSelection fSource;


    public MoveDialog(Shell shell, BugzillaProvider provider, IStructuredSelection source) {
        super(shell, "Move", DEFAULT_WIDTH_IN_CHARS, SWT.DEFAULT, 0, HEIGHT_OFFSET);
        fProvider= provider;
        fSource= source;
    }

    protected Composite createMainDialogArea(Composite parent) {
        
        final Composite composite= new Composite(parent, SWT.NONE);
        composite.setLayout(new GridLayout(1, false));
        
        fSelector= new LocationSelectorField(composite);
        
        setComplete(true);
        return composite;
    }
    
    protected void setErrorMessage(Object key, String message) {
        super.setErrorMessage(key, message);
    }

    
    public BugzillaContainer getContainer() {
        return fSelector.getSelection();
    }
}
