/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.dialogs;


import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.eclipse.team.bugs.dialogs.StatusDialog;
import org.eclipse.team.bugs.tools.SWTUtils;

/**
 * Display a dialog to add a new bug to one of the bug
 * tracking systems.
 */
public class NewBugDialog extends StatusDialog {

    private final class IDField implements ModifyListener {
        
        private final Text fIDText;
        private String fID;
        
        public IDField(Composite composite) {
            final Label label= new Label(composite, SWT.WRAP);
            label.setLayoutData(SWTUtils.createHFillGridData());
            label.setText("Bug ID:");
            fIDText= new Text(composite, SWT.SINGLE | SWT.BORDER);
            fIDText.setLayoutData(SWTUtils.createHFillGridData());
            fIDText.addModifyListener(this);
            fIDText.setFocus();
            fID= null;
        }
        
        public String getID() {
            return fID;
        }
        
        public void modifyText(ModifyEvent e) {
            final String text= fIDText.getText().trim();
            try {
                Integer.parseInt(text);
                fID= text;
                setErrorMessage(this, null);
            } catch (NumberFormatException x) {
                fID= null;
                setErrorMessage(this, "Please enter a valid bug ID.");
            }
        }
    }
    
    protected void setErrorMessage(Object key, String message) {
        super.setErrorMessage(key, message);
    }

    private IDField fIDField;
     
    public NewBugDialog(Shell shell) {
        super(shell, "Add Bug Report");
    }

    public String getID() {
        return fIDField.getID();
    }
    
    protected Composite createMainDialogArea(Composite parent) {
        
        final Composite composite= new Composite(parent, SWT.NONE);
        composite.setLayout(new GridLayout(1, false));
        
        fIDField= new IDField(composite);
        
        setComplete(false);

        return composite;
    }
 }    

