/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.model;

import java.io.BufferedReader;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.StringWriter;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.team.bugs.extension.BugsException;
import org.eclipse.team.bugzilla.BugzillaException;
import org.eclipse.team.bugzilla.BugzillaPlugin;
import org.eclipse.team.bugzilla.datatypes.AttachmentData;
import org.eclipse.team.bugzilla.datatypes.AttachmentDescription;

/**
 * A model element representing an attachment. It is always the child of a comment.
 */
public class BugzillaAttachment extends BugzillaModel implements IRemoteModel {
    
    private AttachmentDescription fDescription;
    
    public BugzillaAttachment(BugzillaComment comment, AttachmentDescription description) {
        super();
        fDescription= description;
        setParent(comment);
    }

    public AttachmentData getData() {
        return getBugzillaProvider().getDataCache().getAttachment(fDescription);
    }
    
    public String getDataAsString() {
        final StringWriter buffer= new StringWriter();
        final BufferedReader reader= new BufferedReader(new InputStreamReader(new ByteArrayInputStream(getData().data)));
        int c;
        try {
            while ((c= reader.read()) != -1)
                buffer.write(c);
        } catch (IOException e) {
            // ignore, this shouldn't happen!
            BugzillaPlugin.log(BugsException.asBugsException(e));
        }
        return buffer.toString();
    }

    public AttachmentDescription getDescription() {
        return fDescription;
    }
 
    public boolean hasLocalContent() {
        return getData() != null;
    }

   public void refresh(IProgressMonitor monitor) throws BugzillaException {
        getBugzillaProvider().getDataCache().refreshAttachments(new AttachmentDescription[] { fDescription }, monitor);
    }
   
   /* (non-Javadoc)
    * @see org.eclipse.team.bugzilla.model.BugzillaModel#update()
    */
   public void update() {
       // TODO Auto-generated method stub
       super.update();
   }

	/* (non-Javadoc)
	 * @see org.eclipse.team.bugzilla.model.BugzillaModel#getId()
	 */
	public String getID() {
	    return fDescription.getID();
	}
	
	/* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.model.IRemoteModel#needsRefresh()
     */
    public boolean needsRefresh() {
        return getData() == null;
    }
    
    /* (non-Javadoc)
     * @see java.lang.Object#toString()
     */
    public String toString() {
        return "attachment #" + getID();
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.model.BugzillaModel#hadErrors()
     */
    public boolean hadErrors() {
        if (getBugzillaProvider() == null)
            return false;
        return getBugzillaProvider().getDataCache().hadErrorsForAttachment(fDescription);
    }
}
