/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.operations;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.eclipse.jface.util.Assert;
import org.eclipse.team.bugs.extension.BugsException;
import org.eclipse.team.bugzilla.BugzillaException;
import org.eclipse.team.bugzilla.datatypes.AttachmentData;
import org.eclipse.team.bugzilla.datatypes.AttachmentDescription;
import org.eclipse.team.bugzilla.datatypes.BugzillaConfiguration;
import org.eclipse.team.bugzilla.datatypes.QueryData;
import org.eclipse.team.bugzilla.datatypes.QueryURL;
import org.eclipse.team.bugzilla.datatypes.ReportData;

/**
 * 
 */
public class CachedOperations {
    
    private BugzillaConfiguration fConfiguration;
    private BugzillaOperations fOperations;
    
    public CachedOperations(BugzillaConfiguration configuration) {
        fConfiguration= configuration;
    }
    
    public void setConfiguration(BugzillaConfiguration configuration) {
        fConfiguration= configuration;
        fOperations= null;
    }
    
    public BugzillaConfiguration getConfiguration() {
        return fConfiguration;
    }
    
    public ReportData getReportData(IProgressMonitor monitor, String id) throws BugzillaException {
        Assert.isNotNull(fConfiguration);
        if (fOperations != null)
            return fOperations.getReportData(monitor, fConfiguration, id);
        return getOperations(monitor).getReportData(monitor, fConfiguration, id);
    }

    public QueryData getQueryData(IProgressMonitor monitor, QueryURL url) throws BugzillaException {
        Assert.isNotNull(fConfiguration);
        if (fOperations != null)
            return fOperations.getQueryData(monitor, fConfiguration, url);
        return getOperations(monitor).getQueryData(monitor, fConfiguration, url);
    }
    
    public AttachmentData getAttachment(IProgressMonitor monitor, AttachmentDescription desc) throws BugzillaException {
        Assert.isNotNull(fConfiguration);
        if (fOperations != null) 
            return fOperations.getAttachment(monitor, fConfiguration, desc);
        return getOperations(monitor).getAttachment(monitor, fConfiguration, desc);
    }
    
    public String getReportIdFromURL(String url) throws BugsException {
        Assert.isNotNull(fConfiguration);
        if (fOperations != null) {
            return fOperations.getReportIDFromURL(fConfiguration, url);
        }
        return getOperations(new NullProgressMonitor()).getReportIDFromURL(fConfiguration, url);
    }
    
    public String getQueryURL(String url) throws BugsException {
        Assert.isNotNull(fConfiguration);
        if (fOperations != null) {
            return fOperations.getQueryURL(fConfiguration, url);
        }
        return getOperations(new NullProgressMonitor()).getQueryURL(fConfiguration, url);
    }
    
    public boolean isCached() {
        return fOperations != null;
    }
    
    public BugzillaOperations getOperations() {
        return fOperations;
    }
    
    public BugzillaOperations getOperations(IProgressMonitor monitor) throws BugzillaException {
        return fOperations= BugzillaOperations.getOperations(monitor, fConfiguration);
    }
}
