/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.persistence;

import org.eclipse.team.bugzilla.BugzillaException;
import org.eclipse.team.bugzilla.datatypes.BugzillaConfiguration;
import org.eclipse.team.bugzilla.model.BugzillaContainer;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.eclipse.team.bugzilla.model.BugzillaProvider;
import org.osgi.service.prefs.Preferences;

/**
 * Adapter for persisting and retoring a bugzilla provider
 */
public class ProviderPersistenceAdapter extends ContainerPersistenceAdapter {

    protected String getType() {
        return PersistenceManager.PROVIDER;
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.persistence.ContainerPersistenceAdapter#store(org.eclipse.team.bugzilla.model.BugzillaModel, org.osgi.service.prefs.Preferences)
     */
    protected void store(BugzillaModel element, Preferences node) {
        super.store(element, node);
        if (element instanceof BugzillaProvider) {
            storeUrl(node, ((BugzillaProvider)element).getConfiguration().getBaseURL());
        }
    }

    protected BugzillaModel restore(BugzillaContainer parent, Preferences node, String id, String name) throws BugzillaException {
        final String url= getUrl(node);
        if (empty(url))
            throw new BugzillaException(BugzillaException.PERSISTENCE_READ_ERROR, "URL empty.");
        if (empty(name)) 
            name = url;
        final BugzillaConfiguration configuration= new BugzillaConfiguration(name, url);
        final BugzillaProvider provider= new BugzillaProvider(null, configuration);
        return provider;
    }

}