package org.eclipse.team.bugzilla.testing;

import java.util.HashSet;

/**
 * Represents a user in a <code>MockBugzillaServer</code>.
 * A user has a user name, a password, and an email address.
 * @author ifoox
 *
 */
public class MockBugzillaUser {
	
	protected String fUserName;
	/** Unprotected account if set to <code>null</code> */
	protected String fPassword;
	protected String fEMail;
	protected static HashSet users;
		
	/**
	 * Creates a new <code>MockBugzillauser</code> with the given
	 * username and password and email address
	 * @param username the desired username
	 * @param password the desired password
	 * @param email the desired email
	 */	
	public MockBugzillaUser(String username, String password, String email){
		this.fUserName = username;
		this.fPassword = password;
		this.fEMail = email;
	}

	/**
	 * Returns the password of this <code>MockBugzillaUser</code>.
	 * 
	 * @return the password of this <code>MockBugzillaUser</code>
	 */
	public String getPassword() {
		return fPassword;
	}

	/**
	 * Sets the password of this <code>MockBugzillaUser</code> to the given 
	 * password. <code>null</code> and empty <code>String</code> password are considered 
	 * equivalent.
	 * 
	 * @param newPass the new value of the password
	 */
	public void setPassword(String newPass){
		
		// set to null if we have an empty string password
		if (newPass != null && newPass.equals("")) 
			fPassword = null;
		else
			fPassword = newPass;
	}
	
	/**
	 * Gets the user name of this <code>MockBugzillaUser</code>.
	 * Note that the user name cannot be changed since users must be unique
	 * within a bugzilla server, with the key being the user name.
	 * 
	 * @return the user name of this <code>MockBugzillaUser</code>
	 */
	public String getUserName(){
		return fUserName;
	}
	
	/**
	 * Returns the email address of this <code>MockBugzillaUser</code>.
	 * 
	 * @return the email address of this <code>MockBugzillaUser</code>
	 */
	public String getEMail() {
		return fEMail;
	}
	
	/**
	 * Sets the email address of this <code>MockBugzillaUser</code> to the 
	 * given value.
	 * 
	 * @param newEMail the new value of the email address
	 */
	public void setEmail(String newEMail) {
		this.fEMail = newEMail;
	}
	
	/**
	 * Attempts to authenticate the <code>user</code> by comparing the given
	 * password with this <code>User</code>'s password.
	 * <code>null</code> and empty <code>String</code> password are considered 
	 * equivalent.
	 * 
	 * @param pass password that has to be authenticated
	 * @return <code>true</code> if password was accepted <code>false</code> otherwise
	 */
	public boolean authenticate(String pass){
		// we let allow the use of either null or "" for an empty password
		if ((fPassword == null || fPassword.equals("")) && 
				(pass == null || pass.equals("")))
			return true;
		// if one is null but not the other: fail
		else if (fPassword == null)
			return false;
		
		return fPassword.equals(pass);
	}
}
