/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.view;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.team.bugzilla.tools.BugzillaSelection;
import org.eclipse.team.bugzilla.tools.IBugzillaSelectionListener;
import org.eclipse.team.bugzilla.tools.IBugzillaSelectionProvider;


class BugzillaSelectionProvider implements IBugzillaSelectionProvider, ISelectionChangedListener {
    
    private final Collection fListeners;
    private BugzillaSelection fSelection;
    
    public BugzillaSelectionProvider() {
        fListeners= new ArrayList();
        fSelection= new BugzillaSelection();
    }

    public void selectionChanged(SelectionChangedEvent event) {
        fSelection= new BugzillaSelection(event.getSelection());
        for (Iterator iter = fListeners.iterator(); iter.hasNext();) {
            ((IBugzillaSelectionListener)iter.next()).selectionChanged(fSelection);
        }
    }

    public BugzillaSelection getSelection() {
        return fSelection;
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.tools.IBugzillaSelectionProvider#addListener(org.eclipse.team.bugzilla.tools.IBugzillaSelectionListener)
     */
    public void addListener(IBugzillaSelectionListener listener) {
        if (!fListeners.contains(listener))
            fListeners.add(listener);
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.tools.IBugzillaSelectionProvider#removeListener(org.eclipse.team.bugzilla.tools.IBugzillaSelectionListener)
     */
    public void removeListener(IBugzillaSelectionListener listener) {
        fListeners.remove(listener);
    }
}