/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.view;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.dnd.DND;
import org.eclipse.swt.dnd.DragSourceEvent;
import org.eclipse.swt.dnd.DragSourceListener;
import org.eclipse.swt.dnd.Transfer;
import org.eclipse.team.bugs.extension.IViewerProxy;
import org.eclipse.team.bugs.internal.views.dnd.BugsDragDropAdapter;
import org.eclipse.team.bugzilla.model.BugzillaContainer;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.eclipse.team.bugzilla.model.BugzillaProvider;
import org.eclipse.team.bugzilla.tools.BugzillaSelection;


class DragListener extends BugsDragDropAdapter implements DragSourceListener {
    
    private final IViewerProxy fProxy;
    private IStructuredSelection fDraggedSelection;
    private BugzillaContainer fContainer;
    
    public DragListener(IViewerProxy proxy) {
        fProxy= proxy;
        final Transfer [] transfers= new Transfer [] { BugzillaTransfer.getInstance() };
        fProxy.addDragSupport(transfers, this);
    }
    
    public void dragStart(DragSourceEvent event) {
        event.doit= validateSelection(fProxy.getSelection());
        fDraggedSelection= event.doit ? fProxy.getSelection() : null;
    }

    public void dragSetData(DragSourceEvent event) {
        if (BugzillaTransfer.getInstance().isSupportedType(event.dataType)) {
            event.data= fProxy.getSelection().toList().toArray(new BugzillaModel [fProxy.getSelection().size()]);
        }
    }
    
    private boolean validateSelection(IStructuredSelection selection) {
        if (selection.isEmpty())
            return false;
        fContainer= new BugzillaSelection(selection).getCommonParent();
        if (fContainer == null) 
            return false;
        
        for (Iterator iter = selection.iterator(); iter.hasNext();) {
            if (!BugzillaTransfer.isSupported(iter.next()))
                return false;
        }
        return true;
    }

    public void dragFinished(DragSourceEvent event) {
        if (!event.doit) {
            fDraggedSelection= null;
            return;
        }
        if (event.detail == DND.DROP_MOVE) {
            final BugzillaContainer parent= new BugzillaSelection(fDraggedSelection).getCommonParent();
            if (!parent.canModifyChildren())
                return;
            final List toRemove= new ArrayList();
            for (final Iterator iter = fDraggedSelection.toList().iterator(); iter.hasNext();) {
                final BugzillaModel child= (BugzillaModel)iter.next();
                if (!child.isReadOnly())
                    toRemove.add(child);
            }
            parent.removeChildren((BugzillaModel [])toRemove.toArray(new BugzillaModel[toRemove.size()]));
        }
    }
    
    public BugzillaProvider getSourceProvider() {
        if (fContainer != null)
            return fContainer.getBugzillaProvider();
        return null;
    }
    
    public BugzillaContainer getSourceContainer() {
        return fContainer;
    }
    
    public IStructuredSelection getDraggedSelection() {
        return fDraggedSelection;
    }
}