/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.wizards;

import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;

import org.eclipse.jface.wizard.WizardPage;

/**
 * A basic WizardPage derrivative that provides an easy way to set the
 * error message on the page and control blocking fields.
 */
public abstract class StatusWizardPage extends WizardPage {

    private final Map fDisabled;
    private final Map fErrorMessages;

    protected StatusWizardPage(String pageName) {
        super(pageName);
        fErrorMessages= new HashMap();
        fDisabled= new HashMap();
    }

	public void setErrorMessage(Object key, String message) {

	    fDisabled.remove(key);
	    final boolean error = (message != null);
	    if (error) {
	        fErrorMessages.put(key, message);
	        setErrorMessage(message);
	        setPageComplete(false);
	    } else {
	        fErrorMessages.remove(key);
	        final boolean notComplete= fErrorMessages.size() > 0 || fDisabled.size() > 0;
	        setErrorMessage(getNextMessage());
	        setPageComplete(!notComplete);
	    }
	}
	
	public void setBlocker(Object key, boolean block) {
	    fDisabled.put(key, block ? Boolean.TRUE : Boolean.FALSE);
	}
	
	private String getNextMessage() {
        if (fErrorMessages.size() == 0)
            return null;
        final Entry entry= (Entry)fErrorMessages.entrySet().iterator().next();
        return (String)entry.getValue();
	}

    

}
