/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.xml;

import java.util.HashMap;

import org.xml.sax.SAXException;

/**
 * 
 */
public class LookupTable implements Tokens {
    
    private final static HashMap fHashTable= new HashMap();
    
    static {
        fHashTable.put("bugzilla", new Integer(BUGZILLA)); //$NON-NLS-1$
        fHashTable.put("bug", new Integer(BUG)); //$NON-NLS-1$
        fHashTable.put("bug_id", new Integer(BUG_ID)); //$NON-NLS-1$
        fHashTable.put("bug_status", new Integer(BUG_STATUS)); //$NON-NLS-1$
        fHashTable.put("product", new Integer(PRODUCT)); //$NON-NLS-1$
        fHashTable.put("priority", new Integer(PRIORITY)); //$NON-NLS-1$
        fHashTable.put("version", new Integer(VERSION)); //$NON-NLS-1$
        fHashTable.put("rep_platform", new Integer(REP_PLATFORM)); //$NON-NLS-1$
        fHashTable.put("assigned_to", new Integer(ASSIGNED_TO)); //$NON-NLS-1$
        fHashTable.put("delta_ts", new Integer(DELTA_TS)); //$NON-NLS-1$
        fHashTable.put("component", new Integer(COMPONENT)); //$NON-NLS-1$
        fHashTable.put("reporter", new Integer(REPORTER)); //$NON-NLS-1$
        fHashTable.put("target_milestone", new Integer(TARGET_MILESTONE)); //$NON-NLS-1$
        fHashTable.put("bug_severity", new Integer(BUG_SEVERITY)); //$NON-NLS-1$
        fHashTable.put("creation_ts", new Integer(CREATION_TS)); //$NON-NLS-1$
        fHashTable.put("qa_contact", new Integer(QA_CONTACT)); //$NON-NLS-1$
        fHashTable.put("op_sys", new Integer(OP_SYS)); //$NON-NLS-1$
        fHashTable.put("resolution", new Integer(RESOLUTION)); //$NON-NLS-1$
        fHashTable.put("bug_file_loc", new Integer(BUG_FILE_LOC)); //$NON-NLS-1$
        fHashTable.put("short_desc", new Integer(SHORT_DESC)); //$NON-NLS-1$
        fHashTable.put("keywords", new Integer(KEYWORDS)); //$NON-NLS-1$
        fHashTable.put("status_whiteboard", new Integer(STATUS_WHITEBOARD)); //$NON-NLS-1$
        fHashTable.put("dependson", new Integer(DEPENDSON)); //$NON-NLS-1$
        fHashTable.put("blocks", new Integer(BLOCKS)); //$NON-NLS-1$
        fHashTable.put("cc", new Integer(CC)); //$NON-NLS-1$
        fHashTable.put("long_desc", new Integer(LONG_DESC)); //$NON-NLS-1$
        fHashTable.put("attachment", new Integer(ATTACHMENT)); //$NON-NLS-1$
        fHashTable.put("who", new Integer(WHO)); //$NON-NLS-1$
        fHashTable.put("bug_when", new Integer(BUG_WHEN)); //$NON-NLS-1$
        fHashTable.put("thetext", new Integer(THETEXT)); //$NON-NLS-1$
        fHashTable.put("attachid", new Integer(ATTACHID)); //$NON-NLS-1$
        fHashTable.put("date", new Integer(DATE)); //$NON-NLS-1$
        fHashTable.put("desc", new Integer(DESC)); //$NON-NLS-1$
        fHashTable.put("type", new Integer(TYPE)); //$NON-NLS-1$
        fHashTable.put("data", new Integer(DATA)); //$NON-NLS-1$
        fHashTable.put("error", new Integer(ERROR)); //$NON-NLS-1$
        fHashTable.put("urlbase", new Integer(URLBASE)); //$NON-NLS-1$
        fHashTable.put("maintainer", new Integer(MAINTAINER)); //$NON-NLS-1$
        fHashTable.put("exporter", new Integer(EXPORTER)); //$NON-NLS-1$
        fHashTable.put("NotFound", new Integer(VALUE_NOTFOUND)); //$NON-NLS-1$
        fHashTable.put("NotPermitted", new Integer(VALUE_NOTPERMITTED)); //$NON-NLS-1$
        fHashTable.put("InvalidBugId", new Integer(VALUE_INVALIDBUGID)); //$NON-NLS-1$
        fHashTable.put("ctype", new Integer(CTYPE)); //$NON-NLS-1$
    }

    /**
     * Returns an int value representing the token.
     * 
     * @param token The string identifier to parse.
     * @return An int value representing the recognized token.
     * @throws SAXException if token isn't a recognized token.
     */
    public static int get(String token) throws SAXException {
        
        final Integer value= (Integer)fHashTable.get(token);
        
        if (value == null) {
            //throw new SAXException("Invalid token: " + token);
        	return UNKOWN_TOKEN;
        }
        
        return value.intValue();
    }
      
    private LookupTable() {}

}
