/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.xml;

import java.io.IOException;
import java.io.StringReader;

import javax.xml.parsers.FactoryConfigurationError;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;

import org.eclipse.team.bugzilla.BugzillaException;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * A wrapper class for convenient use of XML SAX parsers.
 */
public final class Parser {
    
    private SAXParser fParser;
    
    public void parse(String source, DefaultHandler handler) throws BugzillaException {
        try {
            fParser.parse(new InputSource(new StringReader(source)), handler);
        } catch (Exception e) {
            handleError(e);
        }
     }

    public Parser(boolean validating, boolean namespaceAware) throws BugzillaException {
        try {
    	    final SAXParserFactory factory= SAXParserFactory.newInstance();
    	    factory.setValidating(validating);
    	    factory.setNamespaceAware(namespaceAware);
    	    fParser= factory.newSAXParser();
    	} catch (Exception e) {
    	    handleError(e);
    	}
    }
    
    private void handleError(Throwable e) throws BugzillaException {
        
        if (e instanceof ParserConfigurationException) 
            throw new BugzillaException("Error configuring the XML parser", e);
        
        if (e instanceof FactoryConfigurationError)
            throw new BugzillaException("Error configuring the XML Parser Factory", e);
        
        if (e instanceof IOException) 
            throw new BugzillaException(BugzillaException.IO_ERROR, "IO error while parsing the XML string", e);
        
        if (e instanceof SAXException)
            throw new BugzillaException(BugzillaException.XML_ERROR, "Error while parsing the XML string", e);
        
        throw new BugzillaException("Error: " + e.getMessage(), e);
    }
}
